@@ -1,7 +1,7 @@
 """
 Type annotations for ssm service client waiters.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters/)
 
 Usage::
 
@@ -29,7 +29,7 @@ __all__ = ("CommandExecutedWaiter",)
 class CommandExecutedWaiter(Boto3Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Waiter.CommandExecuted)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecutedwaiter)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters/#commandexecutedwaiter)
     """
 
     def wait(
@@ -38,9 +38,9 @@ class CommandExecutedWaiter(Boto3Waiter):
         CommandId: str,
         InstanceId: str,
         PluginName: str = ...,
-        WaiterConfig: WaiterConfigTypeDef = ...
+        WaiterConfig: "WaiterConfigTypeDef" = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Waiter.CommandExecuted.wait)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecutedwaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters/#commandexecutedwaiter)
         """
